.. _report:

Tax-Brain Report Generation
======================================

**report**

taxbrain.report
------------------------------------------

.. currentmodule:: taxbrain.report

.. automodule:: taxbrain.report
  :members: report
